<?php

namespace FiloBlu\Refilo\Model\Indexer\Provider;

use FiloBlu\Refilo\Model\Indexer\Core\Provider\QueryProviderInterface;
use Magento\Framework\App\ResourceConnection;

class PriceProvider implements QueryProviderInterface
{
    /** @var null */
    protected $ids = null;
    /** @var int */
    protected $website;
    /** @var ResourceConnection */
    private $resourceConnection;
    /** @var array */
    private $bindings = [];

    /**
     * PriceProvider constructor.
     * @param ResourceConnection $resourceConnection
     */
    public function __construct(
        ResourceConnection $resourceConnection
    ) {
        $this->resourceConnection = $resourceConnection;
    }

    public function getQuery(): string
    {
        $connection = $this->resourceConnection->getConnection();
        $priceTable = $connection->getTableName('catalog_product_index_price');

        $select = $connection->select();
        $select->from(
            $priceTable,
            [
                '_id' => 'entity_id',
                'website_id' => 'website_id',
                'final_price' => 'final_price',
                'customer_group' => 'customer_group_id',
                'min_price' => 'min_price',
                'max_price' => 'max_price'
            ]
        );

        if ($this->ids !== null) {
            $select->where('entity_id IN (' . implode(',', $this->ids) . ')');
        }

        if ($this->website !== null) {
            $select->where("website_id = {$this->website}");
        }

        return $select->__toString();
    }

    public function getBindings(): array
    {
        return $this->bindings;
    }

    public function filter(array $ids): QueryProviderInterface
    {
        $this->ids = $ids;
        return $this;
    }

    public function website(int $website_id): QueryProviderInterface
    {
        $this->website = $website_id;
        return $this;
    }
}
